Home
last modified time | relevance | path

Searched refs:faster (Results 1 – 25 of 182) sorted by relevance

12345678

/freebsd-12.1/contrib/unbound/compat/
H A Dgetentropy_solaris.c256 int save_errno = errno, e, pgs = getpagesize(), faster = 0, repeat; in getentropy_fallback() local
272 faster = 1; in getentropy_fallback()
275 faster = 0; in getentropy_fallback()
299 if (!faster) { in getentropy_fallback()
H A Dgetentropy_osx.c208 int save_errno = errno, e, pgs = getpagesize(), faster = 0, repeat; in getentropy_fallback() local
231 faster = 1; in getentropy_fallback()
234 faster = 0; in getentropy_fallback()
279 if (!faster) { in getentropy_fallback()
H A Dgetentropy_linux.c336 int save_errno = errno, e, pgs = getpagesize(), faster = 0, repeat; in getentropy_fallback() local
351 faster = 1; in getentropy_fallback()
354 faster = 0; in getentropy_fallback()
379 if (!faster) { in getentropy_fallback()
/freebsd-12.1/secure/lib/libcrypto/arm/
H A Dsha512-armv4.S22 @ This code is ~4.5 (four and a half) times faster than code generated
39 @ one byte in 23.3 cycles or ~60% faster than integer-only code.
H A Dsha256-armv4.S39 @ byte in 12.5 cycles or 23% faster than integer-only code. Snapdragon
/freebsd-12.1/crypto/openssl/doc/man3/
H A DBF_encrypt.pod39 of the faster block ciphers. It is quite a bit faster than DES, and much
40 faster than IDEA or RC2.
H A DBN_add.pod60 This function is faster than BN_mul(r,a,a).
91 (C<r=a^p>). This function is faster than repeated applications of
/freebsd-12.1/contrib/unbound/
H A DREADME6 little faster.
H A DREADME.md26 builtin alternative is equally capable and a little faster.
/freebsd-12.1/contrib/llvm/tools/lld/docs/
H A Dindex.rst5 for system linkers and runs much faster than them. It also provides
85 As you can see, lld is significantly faster than GNU linkers.
144 Noticed that the new linker is much faster than the MSVC linker.
152 that the linker was faster than the GNU linkers, but we weren't sure
/freebsd-12.1/usr.bin/compress/doc/
H A Drevision.log53 * Junk chaining; replace with the simpler (and, on the VAX, faster)
102 * save much memory. Do unsigned compares where possible (faster on
/freebsd-12.1/contrib/bzip2/
H A DREADME68 effort to upgrade to use version 1.0, since it is both faster and more
147 * Approx 10% faster compression, 30% faster decompression
/freebsd-12.1/sys/gnu/dts/arm/
H A Domap-gpmc-smsc9221.dtsi6 * or smsc 9218) has faster timings, leading to higher
/freebsd-12.1/gnu/usr.bin/grep/
H A DREADME13 look at every character. The result is typically many times faster
/freebsd-12.1/sys/contrib/libsodium/
H A DChangeLog3 - Signatures computations and verifications are now way faster on
25 - Argon2 and scrypt are slightly faster on Linux.
123 - SHA-2 is about 20% faster, which also gives a speed boost to
161 - AVX2 detection was fixed, resulting in faster Blake2b hashing on
195 - Some implementations are now slightly faster when using the Clang
231 Intel platforms. `crypto_generichash()` is now faster than MD5 and SHA1
454 - poly1305-ref has been replaced by a faster implementation,
/freebsd-12.1/sys/contrib/zstd/
H A DNEWS2 perf: faster speed (especially decoding speed) on recent cpus (haswell+)
5 cli : asynchronous compression by default, for faster experience (use --single-thread for former be…
7 cli : added command --fast=#, for faster compression modes
20 perf: faster zstd_opt strategy (levels 16-19)
142 lib : improved : faster decompression speed at ultra compression settings and 32-bits mode
/freebsd-12.1/contrib/tcsh/nls/C/
H A Dset1116 -f start faster by ignoring the start-up file \n\
/freebsd-12.1/contrib/gcc/config/sparc/
H A Dlb1spl.asm103 ! ??? This routine could be made faster if was optimized, and if it was
178 ! ??? This routine could be made faster if was optimized, and if it was
/freebsd-12.1/sys/contrib/zlib/contrib/asm686/
H A DREADME.68644 faster than the code produced by gcc 4.1.
/freebsd-12.1/contrib/gperf/
H A Daclocal.m45 # Find a good install program. We prefer a C program (faster),
/freebsd-12.1/contrib/llvm/include/llvm/IR/
H A DValue.def59 // Having constant first makes the range check for isa<Constant> faster
/freebsd-12.1/contrib/binutils/bfd/
H A DREADME34 Use mmap when accessing files. This is faster on some hosts,
/freebsd-12.1/sys/contrib/zstd/programs/
H A Dzstd.1.md121 The higher the value, the faster the compression speed,
236 algorithm will run faster with d <= _8_.
297 There are 8 strategies numbered from 1 to 8, from faster to stronger:
317 faster, but requires more memory during compression.
/freebsd-12.1/sys/sparc64/conf/
H A DNOTES13 # parts of the system run faster.
/freebsd-12.1/sys/dev/bhnd/cores/chipc/pwrctl/
H A Dbhnd_pwrctl_if.m47 * Request that @p clock (or a faster clock) be enabled on behalf of

12345678